@@ -106,5 +106,5 @@ class Segments:
     @brightness.setter
     def brightness(self, brightness):
         if not 0 <= brightness <= 15:
-            raise ValueError('Brightness must be a value between 0 and 15')
+            raise ValueError("Brightness must be a value between 0 and 15")
         self._segments.brightness = brightness / 15
